==> adsprod-model-1.2.16.1-sources.jar: com/bxm/adsprod/model/dao/ticket/TicketOutsidePosition.java <==
package com.bxm.adsprod.model.dao.ticket;

import java.math.BigInteger;

/**
 * 礼券外投默认广告位
 *
 * @ClassName TicketOutsidePosition
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/6/19 11:56
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/6/19 11:56
 **/
public class TicketOutsidePosition {
    /**
     * 开发者ID
     */
    private String appkey;

    /**
     * 广告位
     */
    private String business;

    /**
     * 活动ID
     */
    private BigInteger activityid;

    /**
     * 用户ID
     */
    private String uid;

    /**
     * 设备类型 1- ？
     */
    private Integer appos;

    /**
     * 奖品类型， 1-奖品 2-礼券
     */
    private Integer awardtype;

    /**
     * 微信 1 or 非微信 0
     */
    private Integer ua;

    /**
     * 礼券ID
     */
    private BigInteger preid;

    /**
     * 礼券请求的状态
     */
    private Integer modeltype;

    /**
     * 素材ID
     */
    private String assetId;

    public String getAssetId() {
        return assetId;
    }

    public void setAssetId(String assetId) {
        this.assetId = assetId;
    }

    public String getAppkey() {
        return appkey;
    }

    public void setAppkey(String appkey) {
        this.appkey = appkey;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public BigInteger getActivityid() {
        return activityid;
    }

    public void setActivityid(BigInteger activityid) {
        this.activityid = activityid;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getAppos() {
        return appos;
    }

    public void setAppos(Integer appos) {
        this.appos = appos;
    }

    public Integer getAwardtype() {
        return awardtype;
    }

    public void setAwardtype(Integer awardtype) {
        this.awardtype = awardtype;
    }

    public Integer getUa() {
        return ua;
    }

    public void setUa(Integer ua) {
        this.ua = ua;
    }

    public BigInteger getPreid() {
        return preid;
    }

    public void setPreid(BigInteger preid) {
        this.preid = preid;
    }

    public Integer getModeltype() {
        return modeltype;
    }

    public void setModeltype(Integer modeltype) {
        this.modeltype = modeltype;
    }

    @Override
    public String toString() {
        return "TicketOutsidePosition{" +
                "appkey='" + appkey + '\'' +
                ", business='" + business + '\'' +
                ", activityid=" + activityid +
                ", uid=" + uid +
                ", appos=" + appos +
                ", awardtype=" + awardtype +
                ", ua=" + ua +
                ", preid=" + preid +
                ", modeltype=" + modeltype +
                '}';
    }


}

==> adsprod-model-2.2.0.0-sources.jar: com/bxm/adsprod/model/dao/ticket/TicketOutsidePosition.java <==
package com.bxm.adsprod.model.dao.ticket;

import org.apache.commons.lang3.StringUtils;

import java.math.BigInteger;

/**
 * 礼券外投默认广告位
 *
 * @ClassName TicketOutsidePosition
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/6/19 11:56
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/6/19 11:56
 **/
public class TicketOutsidePosition {
    /**
     * 开发者ID
     */
    private String appkey;

    /**
     * 广告位
     */
    private String business;

    /**
     * 活动ID
     */
    private BigInteger activityid;

    /**
     * 用户ID
     */
    private String uid;

    /**
     * 设备类型 1- ？
     */
    private Integer appos;

    /**
     * 奖品类型， 1-奖品 2-礼券
     */
    private Integer awardtype;

    /**
     * 微信 1 or 非微信 0
     */
    private Integer ua;

    /**
     * 礼券ID
     */
    private BigInteger preid;

    /**
     * 礼券请求的状态
     */
    private Integer modeltype;

    /**
     * 素材ID
     */
    private String assetId;

    /**
     * 广告位ID
     */
    private String positionId;

    private String userAgent;
    private String refferer;

    @Deprecated
    public String getAssetId() {
        return assetId;
    }
    @Deprecated
    public void setAssetId(String assetId) {
        this.assetId = assetId;
    }

    public String getAppkey() {
        return appkey;
    }

    public void setAppkey(String appkey) {
        this.appkey = appkey;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public BigInteger getActivityid() {
        return activityid;
    }

    public void setActivityid(BigInteger activityid) {
        this.activityid = activityid;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getAppos() {
        return appos;
    }

    public void setAppos(Integer appos) {
        this.appos = appos;
    }

    public Integer getAwardtype() {
        return awardtype;
    }

    public void setAwardtype(Integer awardtype) {
        this.awardtype = awardtype;
    }

    public Integer getUa() {
        return ua;
    }

    public void setUa(Integer ua) {
        this.ua = ua;
    }
    @Deprecated
    public BigInteger getPreid() {
        return preid;
    }
    @Deprecated
    public void setPreid(BigInteger preid) {
        this.preid = preid;
    }

    public Integer getModeltype() {
        return modeltype;
    }

    public void setModeltype(Integer modeltype) {
        this.modeltype = modeltype;
    }

    @Override
    public String toString() {
        return "TicketOutsidePosition{" +
                "appkey='" + appkey + '\'' +
                ", business='" + business + '\'' +
                ", activityid=" + activityid +
                ", uid=" + uid +
                ", appos=" + appos +
                ", awardtype=" + awardtype +
                ", ua=" + ua +
                ", preid=" + preid +
                ", modeltype=" + modeltype +
                '}';
    }

    public String getPositionId() {
        if (StringUtils.isNotEmpty(business)) {
            positionId = appkey + "-" + business.replaceAll("ad-|money-", "");
        }
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    public String getRefferer() {
        return refferer;
    }

    public void setRefferer(String refferer) {
        this.refferer = refferer;
    }
}
